verify_any_slide_has_tries_left

Function verify_any_slide_has_tries_left 

async fn verify_any_slide_has_tries_left(
    conn: &mut PgConnection,
    user_id: Uuid,
    exercise: &Exercise,
    course_or_exam_id: CourseOrExamId,
) -> Result<(), ControllerError>
Rejects a user who has used up the try limit on every slide of the exercise. A slide nobody has submitted to has all its tries left.